@@ -93,24 +93,20 @@ class JobBase(abc.ABC):
         """
         Whether this job is started automatically
 
-        This property is not used by this class itself. It is only a flag that
-        is supposed to be evaluated by any job starting facilities.
-
         If this value is falsy, :meth:`start` must be called manually.
 
-        See also :attr:`prejobs`.
+        See also :attr:`is_enabled`.
         """
-        return (
-            self._autostart
-            and all(
-                (prejob.is_finished or not prejob.is_enabled)
-                for prejob in self.prejobs
-            )
-        )
+        return self._autostart
 
     @property
     def condition(self):
-        """Callable that gets no arguments and is called by :attr:`is_enabled`"""
+        """
+        Callable that gets no arguments and returns whether this job should
+        be :meth:`started <start>`
+
+        See also :attr:`is_enabled`.
+        """
         return self._condition
 
     @condition.setter
@@ -119,19 +115,41 @@ class JobBase(abc.ABC):
             raise TypeError(f'Not callable: {function!r}')
         self._condition = function
 
+    @property
+    def prejobs(self):
+        """
+        Sequence of prerequisite :class:`jobs <upsies.jobs.base.JobBase>`
+
+        All prejobs must be either :attr:`finished <is_finished>` or
+        :attr:`disabled <is_enabled>` before this job can start.
+
+        See also :attr:`is_enabled`.
+        """
+        return self._prejobs
+
+    @prejobs.setter
+    def prejobs(self, prejobs):
+        self._prejobs = tuple(prejobs)
+
     @property
     def is_enabled(self):
         """
-        Return value of :attr:`condition` as :class:`bool`
+        Whether this job is allowed to :meth:`start`
 
-        If this value is `False`, this job must not be started nor included in
-        the UI.
+        A job is enabled if :attr:`autostart` is `True`, :attr:`condition`
+        returns `True`, and all :attr:`prejobs` are either finished or disabled.
 
-        This property must be checked by the UI every time any job finishes.
-        This job must be started and added to the UI if it changes from `False`
-        to `True`.
+        This property must be checked by the UI every time any job finishes. If
+        it is `True`, this job must be :meth:`started <start>` and displayed
+        (unless it is :attr:`hidden`).
         """
-        return bool(self._condition())
+        return (
+            all(
+                (prejob.is_finished or not prejob.is_enabled)
+                for prejob in self.prejobs
+            )
+            and self.condition()
+        )
 
     @property
     def kwargs(self):
@@ -175,20 +193,6 @@ class JobBase(abc.ABC):
         """
         return self._signal
 
-    @property
-    def prejobs(self):
-        """
-        Sequence of prerequisite :class:`jobs <upsies.jobs.base.JobBase>`
-
-        :attr:`autostart` stays `False` until all `prejobs` are either finished
-        or :attr:`disabled <is_enabled>`
-        """
-        return self._prejobs
-
-    @prejobs.setter
-    def prejobs(self, prejobs):
-        self._prejobs = tuple(prejobs)
-
     def __init__(self, *, home_directory=None, cache_directory=None,
                  ignore_cache=False, hidden=False, autostart=True,
                  condition=None, prejobs=(), callbacks={}, **kwargs):
@@ -238,7 +242,11 @@ class JobBase(abc.ABC):
         """
         Do the job, e.g. ask for user input or start a task or subprocess
 
-        This method must not block.
+        This method should not be called directly. Instead, :meth:`start` should
+        be called to benefit from caching, to make sure all conditions are met,
+        etc.
+
+        This method must not block. It should return as quickly as possible.
         """
 
     def start(self):
