@@ -300,8 +300,9 @@ class ChoiceJob(JobBase):
     def start(self):
         super().start()
 
-        # Job is finished right away if output was cached previously
-        if not self.is_finished:
+        # Job is not started if it is disabled.
+        # Job is finished right away if output was cached previously.
+        if self.is_started and not self.is_finished:
             if self._autodetect:
                 autodetected = self._autodetect(self)
                 if autodetected is not None:
