@@ -91,6 +91,9 @@ class CreateTorrentJob(base.JobBase):
         ``"searching"``
             If we are searching for a torrent we can copy hashes from.
 
+        ``"verifying"``
+            If we are hash-checking a potentially matching torrent.
+
         ``""``
             None of the above is happening (e.g. we are getting the file tree).
         """
