@@ -575,11 +575,34 @@ class TrackerJobsBase(abc.ABC):
         """
         return jobs.screenshots.ScreenshotsJob(
             content_path=self.content_path,
-            count=self.options.get('screenshots'),
+            count=self.screenshots_count,
+            from_all_videos=self.screenshots_from_all_videos,
             condition=self.make_job_condition('screenshots_job'),
             **self.common_job_args(),
         )
 
+    @property
+    def screenshots_count(self):
+        """
+        How many screenshots to make
+
+        The default implementation uses :attr:`options`\\ ``[screenshots]`` with
+        `None` as the default value.
+        """
+        return self.options.get('screenshots')
+
+    @property
+    def screenshots_from_all_videos(self):
+        """
+        Whether to make :attr:`screenshots_count` screenshots from all
+        videos or just the first one
+
+        See :meth:`.ScreenshotsJob.initialize`.
+
+        The default implementation is always `False`.
+        """
+        return False
+
     image_host_config = {}
     """
     Dictionary that maps an image hosting service :attr:`~.ImageHostBase.name`
@@ -606,12 +629,10 @@ class TrackerJobsBase(abc.ABC):
                 condition=self.make_job_condition('upload_screenshots_job'),
                 **self.common_job_args(),
             )
-            # Timestamps are calculated in a subprocess, we have to wait for
-            # that until we can set the number of expected screenhots.
-            self.screenshots_job.signal.register(
-                'timestamps',
-                lambda timestamps: imghost_job.set_images_total(len(timestamps)),
-            )
+            # Timestamps and number of screenshots are determined in a
+            # subprocess, we have to wait for that before we can set the number
+            # of expected screenhots.
+            self.screenshots_job.signal.register('screenshots_total', imghost_job.set_images_total)
             # Pass ScreenshotsJob's output to ImageHostJob input.
             self.screenshots_job.signal.register('output', imghost_job.enqueue)
             # Tell imghost_job to finish the current upload and then finish.
