@@ -25,11 +25,11 @@ class MtvTrackerJobs(TrackerJobsBase):
             self.mediainfo_job,
             self.screenshots_job,
             self.upload_screenshots_job,
-            self.scene_check_job,
 
             # Interactive jobs
             self.category_job,
             self.imdb_job,
+            self.scene_check_job,
             self.title_job,
             self.description_job,
         )
@@ -136,15 +136,17 @@ class MtvTrackerJobs(TrackerJobsBase):
         return jobs.dialog.TextFieldJob(
             name=self.get_job_name('title'),
             label='Title',
-            prejobs=(self.category_job,),
+            prejobs=(self.category_job, self.scene_check_job, self.imdb_job),
             text=self.generate_title,
             condition=self.make_job_condition('title_job'),
             **self.common_job_args(),
         )
 
     async def generate_title(self):
+        assert self.scene_check_job.is_finished
+        assert self.imdb_job.is_finished
+
         if self.chosen_release_type in (ReleaseType.movie, ReleaseType.episode):
-            await self.scene_check_job.wait()
             if self.scene_check_job.is_scene_release:
                 # Use the scene release name. We rely on scene_check_job making sure
                 # that the file/directory name is the correct release name.
@@ -153,34 +155,28 @@ class MtvTrackerJobs(TrackerJobsBase):
                 return search_results[0]
 
         # Non-scene release or season pack. We may generate a title.
-        await self.imdb_job.wait()
         await self.release_name.fetch_info(webdb=self.imdb, webdb_id=self.imdb_id)
         return str(self.release_name)
 
     @cached_property
     def description_job(self):
-        # Don't cache job output because the number of screenshots can be
-        # changed by the user between runs.
-        job = jobs.dialog.TextFieldJob(
+        return jobs.dialog.TextFieldJob(
             name=self.get_job_name('description'),
             label='Description',
+            prejobs=(self.mediainfo_job, self.upload_screenshots_job),
+            text=self.generate_description,
             condition=self.make_job_condition('description_job'),
+            autofinish=True,
             read_only=True,
             hidden=True,
+            # Don't cache job output because the number of screenshots can be
+            # changed by the user between runs.
             **self.common_job_args(ignore_cache=True),
         )
-        job.attach_task(
-            job.fetch_text(
-                coro=self.generate_description(),
-                finish_on_success=True,
-            )
-        )
-        return job
 
     async def generate_description(self):
-        # Wait until all screenshots are uploaded
-        await self.mediainfo_job.wait()
-        await self.upload_screenshots_job.wait()
+        assert self.mediainfo_job.is_finished
+        assert self.upload_screenshots_job.is_finished
 
         mediainfo = (
             '[mediainfo]'
