@@ -41,5 +41,13 @@ class PtpTrackerConfig(TrackerConfigBase):
                     max=defaults['screenshots'].max,
                 ),
             },
+            ('--personal-rip', '--pr'): {
+                'help': 'Tag as your own encode',
+                'action': 'store_true',
+            },
+            ('--not-main-movie', '--nmm'): {
+                'help': 'Upload ONLY contains extras, Rifftrax, Workprints',
+                'action': 'store_true',
+            },
         },
     }
