@@ -36,6 +36,11 @@ class scene_search(CommandBase):
             'type': utils.argtypes.release,
             'help': 'Release name or path to release content',
         },
+        ('--predbs', '-p'): {
+            'type': utils.argtypes.comma_separated(utils.argtypes.predb),
+            'help': ('Case-insensitive predb name\n'
+                     'Supported predbs: ' + ', '.join(utils.predbs.predb_names())),
+        },
     }
 
     @utils.cached_property
@@ -46,6 +51,7 @@ class scene_search(CommandBase):
                 cache_directory=self.cache_directory,
                 ignore_cache=self.args.ignore_cache,
                 content_path=self.args.RELEASE,
+                predb=utils.predbs.MultiPredbApi(self.args.predbs),
             ),
         )
 
@@ -65,6 +71,11 @@ class scene_check(CommandBase):
             'type': utils.argtypes.release,
             'help': 'Release name or path to release content',
         },
+        ('--predbs', '-p'): {
+            'type': utils.argtypes.comma_separated(utils.argtypes.predb),
+            'help': ('Case-insensitive predb name\n'
+                     'Supported predbs: ' + ', '.join(utils.predbs.predb_names())),
+        },
     }
 
     @utils.cached_property
@@ -75,5 +86,6 @@ class scene_check(CommandBase):
                 cache_directory=self.cache_directory,
                 ignore_cache=self.args.ignore_cache,
                 content_path=self.args.RELEASE,
+                predb=utils.predbs.MultiPredbApi(self.args.predbs),
             ),
         )
