@@ -2,6 +2,8 @@
 Commands related to torrent files
 """
 
+import aiobtclientapi
+
 from .... import constants, jobs, trackers, utils
 from .base import CommandBase
 
@@ -15,7 +17,7 @@ class torrent_add(CommandBase):
         'CLIENT': {
             'type': utils.argtypes.client,
             'help': ('Case-insensitive BitTorrent client name\n'
-                     'Supported clients: ' + ', '.join(utils.btclients.client_names())),
+                     'Supported clients: ' + ', '.join(aiobtclientapi.client_names())),
         },
         'TORRENT': {
             'nargs': '+',
@@ -29,16 +31,21 @@ class torrent_add(CommandBase):
 
     @utils.cached_property
     def jobs(self):
+        client_name = self.args.CLIENT
+        options = self.get_options('clients', client_name)
         return (
             jobs.torrent.AddTorrentJob(
                 home_directory=self.home_directory,
                 cache_directory=self.cache_directory,
                 ignore_cache=self.args.ignore_cache,
-                client=utils.btclients.client(
-                    name=self.args.CLIENT,
-                    config=self.config['clients'][self.args.CLIENT],
+                client_api=aiobtclientapi.api(
+                    name=client_name,
+                    url=options['url'],
+                    username=options['username'],
+                    password=options['password'],
                 ),
                 download_path=self.args.download_path,
+                check_after_add=options['check_after_add'],
                 enqueue=self.args.TORRENT,
             ),
         )
@@ -92,7 +99,7 @@ class torrent_create(CommandBase):
                         'metavar': 'TORRENT',
                         'help': ('Use hashed pieces from TORRENT instead of generating '
                                  'them again or getting them from '
-                                 f'{utils.fs.tildify_path(constants.GENERIC_TORRENTS_DIRPATH)}.\n'
+                                 f'{utils.fs.tildify_path(constants.GENERIC_TORRENTS_DIRPATH)}\n'
                                  'TORRENT may also be a directory, which is searched recursively '
                                  'for a matching *.torrent file.\n'
                                  "NOTE: This option is ignored if TORRENT doesn't match properly."),
@@ -103,7 +110,7 @@ class torrent_create(CommandBase):
                         'type': utils.argtypes.client,
                         'metavar': 'CLIENT',
                         'help': ('Case-insensitive BitTorrent client name\n'
-                                 'Supported clients: ' + ', '.join(utils.btclients.client_names())),
+                                 'Supported clients: ' + ', '.join(aiobtclientapi.client_names())),
                     },
                     ('--copy-to', '-c'): {
                         'metavar': 'PATH',
@@ -151,19 +158,26 @@ class torrent_create(CommandBase):
     @utils.cached_property
     def add_torrent_job(self):
         if self.args.add_to:
+            client_name = self.args.add_to
+            config = self.config['clients'][client_name]
             add_torrent_job = jobs.torrent.AddTorrentJob(
                 home_directory=self.home_directory,
                 cache_directory=self.cache_directory,
                 ignore_cache=self.args.ignore_cache,
-                client=utils.btclients.client(
-                    name=self.args.add_to,
-                    config=self.config['clients'][self.args.add_to],
+                client_api=aiobtclientapi.api(
+                    name=client_name,
+                    url=config['url'],
+                    username=config['username'],
+                    password=config['password'],
                 ),
                 download_path=utils.fs.dirname(self.args.CONTENT),
+                check_after_add=config['check_after_add'],
             )
             # Pass CreateTorrentJob output to AddTorrentJob input.
             self.create_torrent_job.signal.register('output', add_torrent_job.enqueue)
-            # Tell AddTorrentJob to finish the current upload and then finish.
+            # Finish AddTorrentJob when CreateTorrentJob is finished. The
+            # torrent will be enqueued and AddTorrentJob will finish after
+            # adding the enqueued torrent.
             self.create_torrent_job.signal.register('finished', lambda _: add_torrent_job.finalize())
             return add_torrent_job
 
