@@ -14,6 +14,32 @@ import os
 from . import types
 
 
+def comma_separated(argtype):
+    """
+    Multiple comma-separated values
+
+    :param argtype: Any callable that returns a validated object for one of the
+        comma-separated values or raises :class:`ValueError`, :class:`TypeError`
+        or :class:`argparse.ArgumentTypeError`
+
+    :return: Sequence of `argtype` return values
+    """
+
+    def comma_separated(value):
+        """How many screenshots to make within allowed range"""
+        values = []
+        for string in str(value).split(','):
+            string = string.strip()
+            if string:
+                try:
+                    values.append(argtype(string))
+                except (ValueError, TypeError):
+                    raise argparse.ArgumentTypeError(f'Invalid value: {string}')
+        return values
+
+    return comma_separated
+
+
 def client(value):
     """Name of a BitTorrent client supported by :mod:`aiobtclientapi`"""
     import aiobtclientapi
@@ -98,25 +124,37 @@ def regex(value):
 def release(value):
     """Same as :func:`content`, but doesn't have to exist"""
     from .. import errors
-    from . import scene
+    from . import predbs
     path = str(value)
     try:
-        scene.assert_not_abbreviated_filename(path)
+        predbs.assert_not_abbreviated_filename(path)
     except errors.SceneAbbreviatedFilenameError as e:
         raise argparse.ArgumentTypeError(e)
     else:
         return path
 
 
-def scenedb(value):
-    """Name of a scene release database from :mod:`~.utils.scene`"""
-    from . import scene
-    if value in scene.scenedb_names():
+def predb_name(value):
+    """Name of a scene release database from :mod:`~.utils.predbs`"""
+    from . import predbs
+    if value in predbs.predb_names():
         return value.lower()
     else:
         raise argparse.ArgumentTypeError(f'Unsupported scene release database: {value}')
 
 
+def predb(value):
+    """
+    :class:`~.PredbApiBase` instance from a corresponding
+    :attr:`~.PredbApiBase.name`
+    """
+    from . import predbs
+    try:
+        return predbs.predb(value.lower())
+    except ValueError as e:
+        raise argparse.ArgumentTypeError(e)
+
+
 def is_scene(value):
     """
     User-predetermined scene check result
