@@ -36,6 +36,33 @@ def dump(html, filepath):
             f.write(parse(str(html)).prettify())
 
 
+def get(soup, *attributes):
+    """
+    Get `attributes` from `soup`
+
+    These two calls are equivalent if all attributes exist:
+
+    >>> soup.table.tr.td
+    "td value"
+    >>> html.get(soup, "table", "tr", "td")
+    "td value"
+
+    But if any attribute is `None` (which is what :class:`~.bs4.BeautifulSoup`
+    returns for unknown tags), you get `None` instead of forcing you to catch an
+    :class:`AttributeError`:
+
+    >>> soup.table.no_such_attribute.td
+    AttributeError: 'NoneType' object has no attribute 'td'
+    >>> html.get(soup, "table", "no_such_attribute", "td")
+    None
+    """
+    for attr in attributes:
+        soup = getattr(soup, attr, None)
+        if soup is None:
+            return None
+    return soup
+
+
 def as_text(html):
     """Strip HTML tags from string and return text without markup"""
     text = parse(html).get_text()
