@@ -8,14 +8,18 @@ import json
 import os
 import re
 
-from .. import constants, errors
+from .. import constants, errors, utils
 from . import closest_number, fs, os_family, release, subproc
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
+natsort = utils.LazyModule(module='natsort', namespace=globals())
+
+
 NO_DEFAULT_VALUE = object()
 
+
 if os_family() == 'windows':
     _mediainfo_executable = 'mediainfo.exe'
     _ffprobe_executable = 'ffprobe.exe'
@@ -24,6 +28,7 @@ else:
     _ffprobe_executable = 'ffprobe'
 
 
+@functools.lru_cache(maxsize=None)
 def _run_mediainfo(video_file_path, *args):
     fs.assert_file_readable(video_file_path)
     cmd = (_mediainfo_executable, video_file_path) + args
@@ -38,22 +43,36 @@ def _run_mediainfo(video_file_path, *args):
 
 
 @functools.lru_cache(maxsize=None)
-def mediainfo(path):
+def mediainfo(path, only_first=True):
     """
     ``mediainfo`` output as a string
 
     The parent directory of `path` is redacted.
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+    :param bool only_first: Whether to return mediainfo for each video file as a
+        :class:`list` or to return mediainfo of the first video file (see
+        :func:`find_video`)
 
     :raise ContentError: if anything goes wrong
     """
-    mi = _run_mediainfo(first_video(path))
-    parent_dir = os.path.dirname(path)
-    if parent_dir:
-        mi = mi.replace(parent_dir + os.sep, '')
-    return mi
+    def remove_parent_directory(mi, parent_directory=utils.fs.dirname(path)):
+        if parent_directory:
+            return mi.replace(parent_directory + os.sep, '')
+        else:
+            return mi
+
+    if only_first:
+        video_file = find_videos(path)[0]
+        mediainfo = _run_mediainfo(video_file)
+        return remove_parent_directory(mediainfo)
+    else:
+        video_files = find_videos(path)
+        mediainfos = []
+        for video_file in video_files:
+            mediainfo = _run_mediainfo(video_file)
+            mediainfos.append(remove_parent_directory(mediainfo))
+        return mediainfos
 
 
 @functools.lru_cache(maxsize=None)
@@ -62,16 +81,17 @@ def duration(path, default=NO_DEFAULT_VALUE):
     Return video duration in seconds (float) or ``0.0`` if it can't be
     determined
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
     :raise ContentError: if anything goes wrong
     """
-    if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
+    if not os.path.exists(path) and default is not NO_DEFAULT_VALUE:
         return default
-    return _duration(first_video(path))
+    return _duration(find_videos(path)[0])
 
 def _duration(video_file_path):
     try:
@@ -106,8 +126,9 @@ def tracks(path, default=NO_DEFAULT_VALUE):
     ``mediainfo --Output=JSON`` as dictionary that maps each track's ``@type``
     to a list of the tracks
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -115,7 +136,7 @@ def tracks(path, default=NO_DEFAULT_VALUE):
     """
     if default is not NO_DEFAULT_VALUE and not os.path.exists(path):
         return default
-    return _tracks(first_video(path))
+    return _tracks(find_videos(path)[0])
 
 def _tracks(video_file_path):
     stdout = _run_mediainfo(video_file_path, '--Output=JSON')
@@ -138,8 +159,9 @@ def default_track(type, path, default=NO_DEFAULT_VALUE):
     Return default track
 
     :param str type: "video", "audio" or "text"
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -172,8 +194,9 @@ def width(path, default=NO_DEFAULT_VALUE):
     """
     Return displayed width of video file `path`
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -206,8 +229,9 @@ def height(path, default=NO_DEFAULT_VALUE):
     """
     Return displayed height of video file `path`
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -240,8 +264,9 @@ def resolution(path, default=NO_DEFAULT_VALUE):
     """
     Return resolution of video file `path` (e.g. "1080p")
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -309,18 +334,17 @@ def _get_closest_standard_resolution(video_track):
 
     # Find standard aspect ratio closest to the given aspect ratio
     actual_aspect_ratio = round(actual_width / actual_height, 1)
-    _log.debug('Actual resolution: %4d x %4d: aspect ratio: %r',
-               actual_width, actual_height, actual_aspect_ratio)
     std_aspect_ratios = tuple(distances)
     closest_std_aspect_ratio = closest_number(actual_aspect_ratio, std_aspect_ratios)
-    _log.debug('Closest standard aspect ratio: %r', closest_std_aspect_ratio)
 
     # Pick the standard resolution with the lowest distance to the given resolution
     dists = distances[closest_std_aspect_ratio]
     std_width, std_height, std_resolution = sorted(dists.items())[0][1]
 
-    _log.debug('Closest standard resolution: %r x %r -> %r x %r -> %r',
-               actual_width, actual_height, std_width, std_height, std_resolution)
+    _log.debug('Closest standard resolution: %r x %r [%.1f] -> %r x %r [%.1f] -> %r',
+               actual_width, actual_height, actual_aspect_ratio,
+               std_width, std_height, closest_std_aspect_ratio,
+               std_resolution)
     return std_resolution
 
 
@@ -329,8 +353,9 @@ def frame_rate(path, default=NO_DEFAULT_VALUE):
     """
     Return FPS of default video track or ``0.0`` if it can't be determined
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -351,8 +376,9 @@ def bit_depth(path, default=NO_DEFAULT_VALUE):
     """
     Return bit depth of default video track or ``0`` if it can't be determined
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -392,8 +418,9 @@ def hdr_format(path, default=NO_DEFAULT_VALUE):
     Return HDR format based on `hdr_formats`, e.g. "HDR10", or empty string if
     it can't be determined
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -430,8 +457,9 @@ def has_dual_audio(path, default=NO_DEFAULT_VALUE):
     Return `True` if `path` contains multiple audio tracks with different
     languages and one of them is English, `False` otherwise
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -459,8 +487,9 @@ def has_commentary(path, default=NO_DEFAULT_VALUE):
     Return `True` if `path` has an audio track with "Commentary"
     (case-insensitive) in its title, `False` otherwise
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -505,8 +534,9 @@ def audio_format(path, default=NO_DEFAULT_VALUE):
     """
     Return audio format (e.g. "AAC", "MP3") or empty string
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -561,8 +591,9 @@ def audio_channels(path, default=NO_DEFAULT_VALUE):
     """
     Return audio channels (e.g. "5.1") or empty_string
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -599,8 +630,9 @@ def video_format(path, default=NO_DEFAULT_VALUE):
     Return video format or x264/x265/XviD if they were used or empty string if
     it can't be determined
 
-    :param str path: Path to video file or directory. :func:`first_video` is
-        applied.
+    :param str path: Path to video file or directory
+
+        For directories, the first video is used. See :func:`find_videos`.
     :param default: Return value if `path` doesn't exist, raise
         :exc:`~.ContentError` if not provided
 
@@ -625,9 +657,9 @@ def video_format(path, default=NO_DEFAULT_VALUE):
 
 
 @functools.lru_cache(maxsize=None)
-def first_video(path):
+def find_videos(path):
     """
-    Find first video file (e.g. first episode from season)
+    Find video files, excluding nfo, screenshots, samples, etc
 
     Video files are detected by file extension.
 
@@ -637,20 +669,27 @@ def first_video(path):
     Paths to Blu-ray images (directories that contain a "BDMV" directory) are
     simply returned.
 
-    If a file with the typical "SxxE01" exists, it is returned. Otherwise,
-    `path` is filtered through :func:`filter_similar_duration` to avoid samples
-    and such.
+    For paths to DVD images (directories that contain a "VIDEO_TS" directory),
+    return the largest bunch of VOB files.
+
+    For season packs (i.e. directories that contain files with "S..E.." in their
+    name), episodes are returned and all other files are excluded.
+
+    Except for season packs, video files are filtered through
+    :func:`filter_similar_duration` to exclude samples and such.
 
     :param str path: Path to file or directory
 
-    :return: path to video file
-    :rtype: str
+    :return: :class:`list` of video file paths
 
     :raise ContentError: if no video file can be found or if it is unreadable
     """
+    def normalize_files(files):
+        return natsort.natsorted(str(f) for f in files)
+
     if os.path.isdir(path) and os.path.isdir(os.path.join(path, 'BDMV')):
         # Blu-ray image; ffmpeg can read that with the "bluray:" protocol
-        return str(path)
+        return normalize_files([path])
 
     elif os.path.isdir(path) and os.path.isdir(os.path.join(path, 'VIDEO_TS')):
         # DVD image; ffmpeg can't read that properly so we get a list of .VOBs,
@@ -673,13 +712,20 @@ def first_video(path):
     else:
         files = fs.file_list(path, extensions=constants.VIDEO_FILE_EXTENSIONS)
 
-        # Find S\d+E01 in files to get the most common case without getting at
-        # video durations
-        first_video_regex = re.compile(rf'(?:^|{release.DELIM})S\d+E0*1{release.DELIM}')
-        for file in files:
-            if first_video_regex.search(os.path.basename(file)):
-                _log.debug('Found first episode: %r', file)
-                return file
+        # Find episodes in season pack by file name to avoid time consuming
+        # call to filter_similar_duration()
+        episode_regex = re.compile(
+            rf'(?:^|{release.DELIM})'
+            rf'(?i:S|Season{release.DELIM}?)\d+{release.DELIM}?(?i:E|Episode{release.DELIM}?)\d+'
+            rf'{release.DELIM}'
+        )
+        episodes = [
+            file
+            for file in files
+            if episode_regex.search(os.path.basename(file))
+        ]
+        if episodes:
+            return normalize_files(episodes)
 
     if not files:
         raise errors.ContentError(f'{path}: No video file found')
@@ -687,8 +733,7 @@ def first_video(path):
         # To avoid using samples, extras, very short .VOBs (e.g. menus), remove
         # any videos that are very short compared to the average duration.
         considered_files = filter_similar_duration(files)
-        first_file = str(considered_files[0])
-        return first_file
+        return normalize_files(considered_files)
 
 
 @functools.lru_cache(maxsize=None)
