@@ -389,5 +389,5 @@ class Person(str):
     def __repr__(self):
         args = repr(str(self))
         if self.url:
-            args += f', url={self.url}'
+            args += f', url={self.url!r}'
         return f'{type(self).__name__}({args})'
