@@ -26,6 +26,7 @@ class ImdbApi(WebDbApiBase):
     _soup_cache = {}
 
     async def _get_soup(self, path, params={}):
+        path = path.rstrip('/')
         cache_id = (path, tuple(sorted(params.items())))
         if cache_id in self._soup_cache:
             return self._soup_cache[cache_id]
@@ -60,7 +61,6 @@ class ImdbApi(WebDbApiBase):
         _log.debug('Searching IMDb for %s', query)
 
         if query.id:
-            _log.debug('Getting ID: %r', query.id)
             title_english = await self.title_english(query.id)
             title_original = await self.title_original(query.id)
             return [_ImdbSearchResult(
@@ -85,7 +85,6 @@ class ImdbApi(WebDbApiBase):
         else:
             path = 'search/title/'
             params = {'title': query.title_normalized if not query.id else query.id}
-            _log.debug('PARAMS: %r', params)
             if query.type is not ReleaseType.unknown:
                 params['title_type'] = self._title_types[query.type]
             if query.year is not None:
@@ -188,7 +187,7 @@ class ImdbApi(WebDbApiBase):
         return ()
 
     async def poster_url(self, id, season=None):
-        if id:
+        if id and await self.type(id) != ReleaseType.episode:
             soup = await self._get_soup(f'title/{id}/')
             a_tag = soup.find(href=re.compile(r'/title/tt\d+/mediaviewer/'))
             if a_tag:
@@ -199,8 +198,6 @@ class ImdbApi(WebDbApiBase):
                     if (
                         # Only the main poster has no "peek" class
                         'peek' not in tag['class']
-                        # Episodes (still images) have the "kJatiV" class
-                        and 'kJatiV' not in tag['class']
                     )
                 ]
                 if img_tags:
@@ -238,6 +235,44 @@ class ImdbApi(WebDbApiBase):
     )
 
     async def _runtimes(self, id):
+        runtimes = await self._runtimes_new_design(id)
+        if not runtimes:
+            runtimes = await self._runtimes_old_design(id)
+        return runtimes
+
+    async def _runtimes_new_design(self, id):
+        runtimes = {}
+        if id:
+            soup = await self._get_soup(f'title/{id}/technical')
+            runtimes_label_tag = soup.find('button', string=re.compile(r'\bRuntime\b'))
+            if runtimes_label_tag:
+                values_tag = runtimes_label_tag.next_sibling
+                if values_tag:
+                    for li_tag in values_tag.find_all('li'):
+                        li_text = ' '.join(li_tag.stripped_strings)
+
+                        # Examples: 2h 13m (133 min)
+                        #           2h 28m (148 min) (extended) (United States)
+                        #           2h 42m (162 min) 3h 6m (186 min) (director's cut) 3h 35m (215 min) (Ultimate Cut)
+                        #           55m
+                        match = re.search(r'\((\d+)\s*(?:min|m)\)\s*(?:\((.+?)\)|)', li_text)
+                        if not match:
+                            match = re.search(r'^(\d+)\s*(?:min|m)$', li_text)
+
+                        if match:
+                            groups = match.groups()
+                            minutes = int(groups[0])
+                            if len(groups) >= 2:
+                                key = utils.string.capitalize(groups[1]) if groups[1] else 'default'
+                            else:
+                                key = 'default'
+
+                            if not any(regex.search(key) for regex in self._ignored_runtimes_keys):
+                                runtimes[key] = minutes
+
+        return runtimes
+
+    async def _runtimes_old_design(self, id):
         runtimes = {}
         if id:
             soup = await self._get_soup(f'title/{id}/technical')
@@ -275,74 +310,51 @@ class ImdbApi(WebDbApiBase):
 
             # Get summary from dedicated page
             soup = await self._get_soup(f'title/{id}/plotsummary')
-            try:
-                return ''.join(soup.find(id='plot-summaries-content').li.p.strings)
-            except AttributeError:
-                pass
+            candidates = (
+                # Old website design
+                utils.html.get(soup.find(id='plot-summaries-content'), 'li', 'p'),
+                # New website design
+                soup.find(attrs={'data-testid': 'sub-section-summaries'}),
+            )
+            for tag in candidates:
+                if tag:
+                    text = utils.html.as_text(tag)
+                    return re.sub(r'—.*$', '', text).strip()
 
         return ''
 
     async def _title_original(self, id):
         akas = await self._get_akas(id)
-        return akas.get('(original title)', '')
+        return akas.get('original', '')
 
     async def _titles_english(self, id):
-        english_titles = []
-        # Make a list of English titles
         akas = await self._get_akas(id)
-        for regex in self._english_akas_keys:
-            for key, english_title in akas.items():
-                # _log.debug('Matching: %-40r against %s', key, regex.pattern)
-                if regex.search(key):
-                    _log.debug('Found English title: %r: %s', key, english_title)
-                    english_titles.append(english_title)
-        return english_titles
-
-    _english_akas_keys = (
-        re.compile(r'^USA.*English'),
-        re.compile(r'^USA$'),
-        re.compile(r'^World-wide.*English'),
-        re.compile(r'^USA.*reissue'),
-        re.compile(r'^UK$'),
-    )
+        return [akas.get('english', '')]
 
+    @utils.asyncmemoize
     async def _get_akas(self, id):
-        soup = await self._get_soup(f'title/{id}/releaseinfo')
-        akas = {}
+        soup = await self._get_soup(f'title/{id}')
+        main_title = sub_title = None
 
-        def is_item_key_class(class_):
-            # Class may also be named "aka-item__name-empty"
-            return class_ and class_.startswith('aka-item__name')
+        # The big title on the main page. This is usually the English title,
+        # even for non-English movies.
+        tag = soup.find(attrs={'data-testid': 'hero-title-block__title'})
+        if tag:
+            main_title = utils.html.as_text(tag)
 
-        for item in soup.find_all('tr', class_='aka-item'):
-            key_tag = item.find('td', class_=is_item_key_class)
-            key = ''.join(key_tag.stripped_strings).strip()
+        # The small title below the main title. This is the original title for
+        # non-English movies and not displayed for English movies.
+        tag = soup.find(attrs={'data-testid': 'hero-title-block__original-title'})
+        if tag:
+            text = utils.html.as_text(tag)
+            sub_title = re.sub(r'^Original\s+title:\s+', '', text, flags=re.IGNORECASE)
 
-            title_tag = item.find('td', class_='aka-item__title')
-            title = ''.join(title_tag.stripped_strings).strip()
-
-            if title:
-                if not any(regex.search(key) for regex in self._ignored_akas_keys):
-                    # _log.debug('AKA: %r -> %r', key, title)
-                    akas[key] = title
-            #     else:
-            #         _log.debug('AKA not wanted: %r -> %r', key, title)
-            # else:
-            #     _log.debug('AKA empty: %r -> %r', key, title)
-
-        return akas
-
-    _ignored_akas_keys = (
-        re.compile(r'\(TV title\)$'),
-        re.compile(r'\(alternative spelling\)$'),
-        re.compile(r'\(dubbed version\)$'),
-        re.compile(r'\(literal title\)$'),
-        re.compile(r'\(original script title\)$'),
-        re.compile(r'\([\w ]*short title\)$'),  # ([informal|...?] short title)
-        re.compile(r'\(video box title\)$'),
-        re.compile(r'\(working title\)$'),
-        re.compile(r'\(long title\)$'),
-    )
+        if sub_title:
+            # Probably non-English title
+            return {'original': sub_title, 'english': main_title}
+        else:
+            # Probably English title
+            return {'original': main_title, 'english': main_title}
 
     async def type(self, id):
         if id:
